/* _NVRM_COPYRIGHT_BEGIN_
 *
 * Copyright 2001-2002 by NVIDIA Corporation.  All rights reserved.  All
 * information contained herein is proprietary and confidential to NVIDIA
 * Corporation.  Any use, reproduction, or disclosure without the written
 * permission of NVIDIA Corporation is prohibited.
 *
 * _NVRM_COPYRIGHT_END_
 */

#include "nv-misc.h"
#include "os-interface.h"
#include "nv.h"
#include "nv-freebsd.h"


struct nvidia_registry nvreg[] = {
    { "VideoMemoryTypeOverride", "Override Detected VRAM Type",  0, 0 },
    { "EnableVia4x",             "Enable AGP on Via Chipsets",   0, 0 },
    { "EnableALiAGP",            "Enable AGP on ALi Chipsets",   0, 0 },
    { "ReqAGPRate",              "Force AGP Rate",               4, 0 },
    { "EnableAGPSBA",            "Force AGP SBA Setting",        0, 1 },
    { "EnableAGPFW",             "Force AGP FW Setting",         0, 1 },
    { "SoftEDIDs",               "Mobile: Use Software EDIDs",   1, 1 },
    { "Mobile",                  "Mobile: Force Mobile Value",  ~0, 1 },
    { "ResmanDebugLevel",        "Core Resman Debug Level",    0xaaaaaaaa, 0 },
    { NULL,                      "Terminating Entry",            0, 0 }
};


VOID* os_registry_lookup(
    PHWINFO pDev,
    U008 *node,
    U008 *key
)
{
    int i = 0; 
    struct nvidia_registry *entry;

    do {
        entry = &nvreg[i++];
        if (entry->valid && strcmp(entry->name, key) == 0)
            return &entry->data;
    } while (entry->name != NULL);

    return NULL;
}

RM_STATUS os_read_registry_boolean(
    PHWINFO pDev,
    U008 *node,
    U008 *key
)
{
    /*
     * XXX This function is not currently implemented and not required to
     * guarantee the correct behaviour of the module. In the future, this
     * may change, however, the function should be implemented.
     */
    return RM_ERROR;
}

RM_STATUS os_read_registry_binary(
    PHWINFO pDev,
    U008 *node,
    U008 *key,
    U008 *data,
    U032 *len
)
{
    /*
     * XXX This function is not currently implemented and not required to
     * guarantee the correct behaviour of the module. In the future, this
     * may change, however, the function should be implemented.
     */
    return RM_ERROR;
}

RM_STATUS os_write_registry_binary(
    PHWINFO pDev,
    U008 *node,
    U008 *key,
    U008 *data,
    U032 len
)
{
    /*
     * XXX This function is not currently implemented and not required to
     * guarantee the correct behaviour of the module. In the future, this
     * may change, however, the function should be implemented.
     */
    return RM_ERROR;
}

RM_STATUS os_write_registry_dword(
    PHWINFO pDev,
    U008 *node,
    U008 *key,
    U032 data
)
{
    U032 *ptr;

    ptr = os_registry_lookup(pDev, NULL, key);
    if (ptr) {
        *ptr = data;
        return RM_OK;
    }

    return RM_ERROR;
}

RM_STATUS os_read_registry_dword(
    PHWINFO pDev,
    U008 *node,
    U008 *key,
    U032 *data
)
{
    U032 *ptr;

    ptr = os_registry_lookup(pDev, NULL, key);
    if (ptr) {
        *data = *ptr;
        return RM_OK;
    }

    return RM_ERROR;
}

